%define anolis_release 1

# Extract the API major & minor versions, so we can export them below.
# Ensure that the major version is >= 3, since that patch is not yet
# in the tarball.
%global gawk_api_major %%(x=`tar -xf %{SOURCE0} gawk-%{version}/gawkapi.h --to-stdout 2>/dev/null | \
                          grep -i -e "gawk_api_major.*[[:digit:]]" | \
                          grep -o -e "[[:digit:]]"`; \
                          [ "$x" -lt 3 ] && x=3; echo $x)

%global gawk_api_minor %%(tar -xf %{SOURCE0} gawk-%{version}/gawkapi.h --to-stdout 2>/dev/null | \
                          grep -i -e "gawk_api_minor.*[[:digit:]]" | \
                          grep -o -e "[[:digit:]]" || :)

Name:             gawk           
Version:          5.2.2
Release:          %{anolis_release}%{?dist}
Summary:          The GNU version of the AWK text processing utility

License:          GPLv3+ and GPLv2+ and LGPLv2+ and BSD
URL:              https://www.gnu.org/software/gawk/
Source0:          https://ftp.gnu.org/gnu/gawk/gawk-%{version}.tar.xz

Source1:          LICENSE.GPLv2
Source2:          LICENSE.LGPLv2
Source3:          LICENSE.BSD

# these test cases can not pass in mock, but can pass in anolis23
Patch1001:        1001-skip-pma-and-nonfatal3-test.patch

Provides:         /bin/awk /bin/gawk

Provides:         gawk(abi) = %{gawk_api_major}.%{gawk_api_minor}

BuildRequires:    gcc grep ghostscript automake make
BuildRequires:    libsigsegv-devel mpfr-devel readline-devel
BuildRequires:    texinfo-tex texlive-ec texlive-cm-super
BuildRequires:    glibc-all-langpacks bison
Requires:         filesystem >= 3      

%description
gawk is a text processing utility that implements the AWK programming language. 
AWK is designed to manipulate text data and produce formatted reports. gawk is 
a GNU project and it offers many extensions and features beyond the standard AWK.

With gawk, you can easily match patterns in text files, extract or transform 
data, and perform various operations on the records and fields. It is 
considered to be a standard Linux tool for
text processing.

%package devel
Summary:          Header file for gawk extensions development
Requires:         %{name} = %{version}-%{release}

%description devel
This subpackage contains the /usr/include/gawkapi.h header file, which defines 
the interface for writing extensions to gawk in C or C++. Extensions can add 
new variables and functions to gawk and access its internal data structures. 
For more information about gawk extensions, please consult `The GNU Awk 
User's Guide`.

This subpackage is only useful for developers who want to create gawk 
extensions. If you are not developing an extension for gawk, you do not 
need this subpackage.


%package doc
Summary:          Additional documentation for gawk utility
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%description doc
If you install gawk, you will also get two user's guides: `GAWK: Effective AWK 
Programming` and `TCP/IP Internetworking with gawk`. These guides are available 
as info pages, which you can read with any info reader.

However, info pages are not very suitable for printing or viewing images. 
That's why this doc subpackage offers you alternative formats of those guides, 
such as HTML, PDF and PS. These formats can be more convenient if you need to 
consult them frequently, and/or if you don't have Internet access. 

%package all-langpacks
Summary:          Additional localisation files for gawk utility
Supplements: %{name} = %{version}-%{release}
Conflicts: %{name} < 5.0.1-8
%description all-langpacks
The base package of gawk supports only the english localisation. This subpackage
contains additional localisation files.

%prep
%autosetup -p1
cp -a %{SOURCE1} %{SOURCE2} %{SOURCE3} .

%build
autoreconf --force --verbose
%configure
%make_build

%make_build -C doc pdf
mkdir -p html/gawk html/gawkinet
makeinfo --html -I doc -o html/gawk     doc/gawk.texi
makeinfo --html -I doc -o html/gawkinet doc/gawkinet.texi

%check
make check

%install
%make_install

rm -f %{buildroot}%{_bindir}/gawk-%{version}*
rm -f %{buildroot}%{_infodir}/dir
ln -sf gawk %{buildroot}%{_bindir}/awk
ln -sf gawk.1.gz %{buildroot}%{_mandir}/man1/awk.1.gz

ln -sf /usr/share/awk   %{buildroot}%{_datadir}/gawk
ln -sf /usr/libexec/awk %{buildroot}%{_libexecdir}/gawk

%find_lang %{name}

install -m 0755 -d %{buildroot}%{_docdir}/%{name}/html/gawk/
install -m 0755 -d %{buildroot}%{_docdir}/%{name}/html/gawkinet/

install -m 0644 -p html/gawk/*           %{buildroot}%{_docdir}/%{name}/html/gawk/
install -m 0644 -p html/gawkinet/*       %{buildroot}%{_docdir}/%{name}/html/gawkinet/

install -m 0644 -p doc/gawk.{pdf,ps}     %{buildroot}%{_docdir}/%{name}
install -m 0644 -p doc/gawkinet.{pdf,ps} %{buildroot}%{_docdir}/%{name}

%generate_compatibility_deps

%files
%dir %{abidir}
%{_bindir}/*awk
%{abidir}/*awk-option.list
%{_bindir}/gawkbug
%{abidir}/gawkbug-option.list
%{abidir}/*.dump
%{_libdir}/*awk
%{_datadir}/*awk
%{_libexecdir}/*awk
%{_sysconfdir}/profile.d/gawk.*

%{_mandir}/man1/*
%{_mandir}/man3/*
%{_infodir}/*

%doc NEWS README POSIX.STD README_d/README.multibyte
%license COPYING LICENSE.GPLv2 LICENSE.LGPLv2 LICENSE.BSD

%files -f %{name}.lang all-langpacks

%files devel
%{_includedir}/gawkapi.h

%files doc
%doc %{_docdir}/%{name}/gawk.{pdf,ps}
%doc %{_docdir}/%{name}/gawkinet.{pdf,ps}
%doc %{_docdir}/%{name}/html

%changelog
* Tue May 9 2023 Funda Wang <fundawang@yeah.net> - 5.2.2-1
- New version 5.2.2

* Tue Apr 11 2023 Zhongling <zhonglingh@linux.alibaba.com> - 5.2.1-2
- Refactor rpm spec

* Fri Jan 13 2023 Feng Su <sufeng@linux.alibaba.com> - 5.2.1-1
- update to v5.2.1
- skip pma and nonfatal3 test

* Thu Oct 27 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.1.1-2
- optimise spec file

* Mon Mar 07 2022 liuzhilin <liuzhilin@unionech.com> - 5.1.1-1
- Init for Anolis OS 23
